"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getAggRulesITC = void 0;
const utils_1 = require("../../utils");
const AggBlock_1 = require("./AggBlock");
const Avg_1 = require("./Metrics/Avg");
const Cardinality_1 = require("./Metrics/Cardinality");
const ExtendedStats_1 = require("./Metrics/ExtendedStats");
const GeoBounds_1 = require("./Metrics/GeoBounds");
const GeoCentroid_1 = require("./Metrics/GeoCentroid");
const Max_1 = require("./Metrics/Max");
const Min_1 = require("./Metrics/Min");
const PercentileRanks_1 = require("./Metrics/PercentileRanks");
const Percentiles_1 = require("./Metrics/Percentiles");
const ScriptedMetric_1 = require("./Metrics/ScriptedMetric");
const Stats_1 = require("./Metrics/Stats");
const Sum_1 = require("./Metrics/Sum");
const TopHits_1 = require("./Metrics/TopHits");
const ValueCount_1 = require("./Metrics/ValueCount");
const Children_1 = require("./Bucket/Children");
const DateHistogram_1 = require("./Bucket/DateHistogram");
const DateRange_1 = require("./Bucket/DateRange");
const DiversifiedSampler_1 = require("./Bucket/DiversifiedSampler");
const Filter_1 = require("./Bucket/Filter");
const Filters_1 = require("./Bucket/Filters");
const GeoDistance_1 = require("./Bucket/GeoDistance");
const GeohashGrid_1 = require("./Bucket/GeohashGrid");
const Global_1 = require("./Bucket/Global");
const Histogram_1 = require("./Bucket/Histogram");
const IpRange_1 = require("./Bucket/IpRange");
const Missing_1 = require("./Bucket/Missing");
const Nested_1 = require("./Bucket/Nested");
const Range_1 = require("./Bucket/Range");
const ReverseNested_1 = require("./Bucket/ReverseNested");
const Sampler_1 = require("./Bucket/Sampler");
const SignificantTerms_1 = require("./Bucket/SignificantTerms");
const Terms_1 = require("./Bucket/Terms");
const AvgBucket_1 = require("./Pipeline/AvgBucket");
const BucketScript_1 = require("./Pipeline/BucketScript");
const BucketSelector_1 = require("./Pipeline/BucketSelector");
const CumulativeSum_1 = require("./Pipeline/CumulativeSum");
const Derivative_1 = require("./Pipeline/Derivative");
const ExtendedStatsBucket_1 = require("./Pipeline/ExtendedStatsBucket");
const MaxBucket_1 = require("./Pipeline/MaxBucket");
const MinBucket_1 = require("./Pipeline/MinBucket");
const MovingAverage_1 = require("./Pipeline/MovingAverage");
const PercentilesBucket_1 = require("./Pipeline/PercentilesBucket");
const SerialDifferencing_1 = require("./Pipeline/SerialDifferencing");
const StatsBucket_1 = require("./Pipeline/StatsBucket");
const SumBucket_1 = require("./Pipeline/SumBucket");
function getAggRulesITC(opts) {
    const name = (0, utils_1.getTypeName)('AggRules', opts);
    const description = (0, utils_1.desc)(`
    The aggregations framework helps provide aggregated data based on
    a search query. It is based on simple building blocks called aggregations,
    that can be composed in order to build complex summaries of the data.
    [Documentation](https://www.elastic.co/guide/en/elasticsearch/reference/current/search-aggregations.html)
  `);
    return opts.getOrCreateITC(name, () => ({
        name,
        description,
        fields: {
            avg: () => (0, Avg_1.getAvgITC)(opts),
            cardinality: () => (0, Cardinality_1.getCardinalityITC)(opts),
            extended_stats: () => (0, ExtendedStats_1.getExtendedStatsITC)(opts),
            geo_bounds: () => (0, GeoBounds_1.getGeoBoundsITC)(opts),
            geo_centroid: () => (0, GeoCentroid_1.getGeoCentroidITC)(opts),
            max: () => (0, Max_1.getMaxITC)(opts),
            min: () => (0, Min_1.getMinITC)(opts),
            percentile_ranks: () => (0, PercentileRanks_1.getPercentileRanksITC)(opts),
            percentiles: () => (0, Percentiles_1.getPercentilesITC)(opts),
            scripted_metric: () => (0, ScriptedMetric_1.getScriptedMetricITC)(opts),
            stats: () => (0, Stats_1.getStatsITC)(opts),
            sum: () => (0, Sum_1.getSumITC)(opts),
            top_hits: () => (0, TopHits_1.getTopHitsITC)(opts),
            value_count: () => (0, ValueCount_1.getValueCountITC)(opts),
            children: () => (0, Children_1.getChildrenITC)(opts),
            date_histogram: () => (0, DateHistogram_1.getDateHistogramITC)(opts),
            date_range: () => (0, DateRange_1.getAggsDateRangeITC)(opts),
            diversified_sampler: () => (0, DiversifiedSampler_1.getDiversifiedSamplerITC)(opts),
            filter: () => (0, Filter_1.getFilterITC)(opts),
            filters: () => (0, Filters_1.getFiltersITC)(opts),
            geo_distance: () => (0, GeoDistance_1.getGeoDistanceITC)(opts),
            geohash_grid: () => (0, GeohashGrid_1.getGeohashGridITC)(opts),
            global: () => (0, Global_1.getGlobalITC)(opts),
            histogram: () => (0, Histogram_1.getHistogramITC)(opts),
            ip_range: () => (0, IpRange_1.getIpRangeITC)(opts),
            missing: () => (0, Missing_1.getMissingITC)(opts),
            nested: () => (0, Nested_1.getNestedITC)(opts),
            range: () => (0, Range_1.getRangeITC)(opts),
            reverse_nested: () => (0, ReverseNested_1.getReverseNestedITC)(opts),
            sampler: () => (0, Sampler_1.getSamplerITC)(opts),
            significant_terms: () => (0, SignificantTerms_1.getSignificantTermsITC)(opts),
            terms: () => (0, Terms_1.getTermsITC)(opts),
            avg_bucket: () => (0, AvgBucket_1.getAvgBucketITC)(opts),
            bucket_script: () => (0, BucketScript_1.getBucketScriptITC)(opts),
            bucket_selector: () => (0, BucketSelector_1.getBucketSelectorITC)(opts),
            cumulative_sum: () => (0, CumulativeSum_1.getCumulativeSumITC)(opts),
            derivative: () => (0, Derivative_1.getDerivativeITC)(opts),
            extended_stats_bucket: () => (0, ExtendedStatsBucket_1.getExtendedStatsBucketITC)(opts),
            max_bucket: () => (0, MaxBucket_1.getMaxBucketITC)(opts),
            min_bucket: () => (0, MinBucket_1.getMinBucketITC)(opts),
            moving_average: () => (0, MovingAverage_1.getMovingAverageITC)(opts),
            percentiles_bucket: () => (0, PercentilesBucket_1.getPercentilesBucketITC)(opts),
            serial_differencing: () => (0, SerialDifferencing_1.getSerialDifferencingITC)(opts),
            stats_bucket: () => (0, StatsBucket_1.getStatsBucketITC)(opts),
            sum_bucket: () => (0, SumBucket_1.getSumBucketITC)(opts),
            aggs: {
                type: () => [(0, AggBlock_1.getAggBlockITC)(opts)],
                description: 'Aggregation block',
            },
        },
    }));
}
exports.getAggRulesITC = getAggRulesITC;
//# sourceMappingURL=AggRules.js.map