"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getExtendedStatsITC = void 0;
const utils_1 = require("../../../utils");
const Script_1 = require("../../Commons/Script");
const FieldNames_1 = require("../../Commons/FieldNames");
function getExtendedStatsITC(opts) {
    const name = (0, utils_1.getTypeName)('AggsExtendedStats', opts);
    const description = (0, utils_1.desc)(`
    A multi-value metrics aggregation that computes stats over numeric values
    extracted from the aggregated documents. These values can be extracted
    either from specific numeric fields in the documents, or be generated
    by a provided script.
    [Documentation](https://www.elastic.co/guide/en/elasticsearch/reference/current/search-aggregations-metrics-extendedstats-aggregation.html)
  `);
    return opts.getOrCreateITC(name, () => ({
        name,
        description,
        fields: {
            field: (0, FieldNames_1.getNumericFields)(opts),
            sigma: 'Float',
            missing: 'Float',
            script: () => (0, Script_1.getCommonsScriptITC)(opts),
        },
    }));
}
exports.getExtendedStatsITC = getExtendedStatsITC;
//# sourceMappingURL=ExtendedStats.js.map