"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPercentilesITC = void 0;
const utils_1 = require("../../../utils");
const Script_1 = require("../../Commons/Script");
const HDR_1 = require("../../Commons/HDR");
const FieldNames_1 = require("../../Commons/FieldNames");
function getPercentilesITC(opts) {
    const name = (0, utils_1.getTypeName)('AggsPercentiles', opts);
    const description = (0, utils_1.desc)(`
    A multi-value metrics aggregation that calculates one or more percentiles
    over numeric values extracted from the aggregated documents.
    These values can be extracted either from specific numeric fields
    in the documents, or be generated by a provided script.
    [Documentation](https://www.elastic.co/guide/en/elasticsearch/reference/current/search-aggregations-metrics-percentile-aggregation.html)
  `);
    return opts.getOrCreateITC(name, () => ({
        name,
        description,
        fields: {
            field: (0, FieldNames_1.getNumericFields)(opts),
            percents: '[Float]',
            tdigest: `input ${(0, utils_1.getTypeName)('AggsPercentilesTDigest', opts)} {
          compression: Int,
        }`,
            hdr: () => (0, HDR_1.getCommonsHdrITC)(opts),
            missing: 'Float',
            script: () => (0, Script_1.getCommonsScriptITC)(opts),
        },
    }));
}
exports.getPercentilesITC = getPercentilesITC;
//# sourceMappingURL=Percentiles.js.map