"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.prepareConstantScoreInResolve = exports.getConstantScoreITC = void 0;
const Query_1 = require("../Query");
const utils_1 = require("../../../utils");
function getConstantScoreITC(opts) {
    const name = (0, utils_1.getTypeName)('QueryConstantScore', opts);
    const description = (0, utils_1.desc)(`
    A query that wraps another query and simply returns a constant score equal
    to the query boost for every document in the filter.
    [Documentation](https://www.elastic.co/guide/en/elasticsearch/reference/current/query-dsl-constant-score-query.html)
  `);
    return opts.getOrCreateITC(name, () => ({
        name,
        description,
        fields: {
            filter: () => (0, Query_1.getQueryITC)(opts).getTypeNonNull(),
            boost: 'Float!',
        },
    }));
}
exports.getConstantScoreITC = getConstantScoreITC;
function prepareConstantScoreInResolve(constant_score, fieldMap) {
    if (constant_score.filter) {
        constant_score.filter = (0, Query_1.prepareQueryInResolve)(constant_score.filter, fieldMap);
    }
    return constant_score;
}
exports.prepareConstantScoreInResolve = prepareConstantScoreInResolve;
//# sourceMappingURL=ConstantScore.js.map