"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.prepareDisMaxResolve = exports.getDisMaxITC = void 0;
const Query_1 = require("../Query");
const utils_1 = require("../../../utils");
function getDisMaxITC(opts) {
    const name = (0, utils_1.getTypeName)('QueryDisMax', opts);
    const description = (0, utils_1.desc)(`
    A query that generates the union of documents produced by its subqueries,
    and that scores each document with the maximum score for that document
    as produced by any subquery, plus a tie breaking increment
    for any additional matching subqueries.
    [Documentation](https://www.elastic.co/guide/en/elasticsearch/reference/current/query-dsl-dis-max-query.html)
  `);
    return opts.getOrCreateITC(name, () => ({
        name,
        description,
        fields: {
            queries: () => [(0, Query_1.getQueryITC)(opts)],
            boost: 'Float',
            tie_breaker: 'Float',
        },
    }));
}
exports.getDisMaxITC = getDisMaxITC;
function prepareDisMaxResolve(dis_max, fieldMap) {
    if (Array.isArray(dis_max.queries)) {
        dis_max.queries = dis_max.queries.map((query) => (0, Query_1.prepareQueryInResolve)(query, fieldMap));
    }
    return dis_max;
}
exports.prepareDisMaxResolve = prepareDisMaxResolve;
//# sourceMappingURL=DisMax.js.map