"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const ElasticApiParser_1 = __importDefault(require("../ElasticApiParser"));
const FindByIdOutput_1 = require("../types/FindByIdOutput");
function createFindByIdResolver(opts) {
    const { fieldMap, sourceTC, schemaComposer } = opts;
    if (!fieldMap || !fieldMap._all) {
        throw new Error('opts.fieldMap for Resolver findById() should be fieldMap of FieldsMapByElasticType type.');
    }
    if (!sourceTC || sourceTC.constructor.name !== 'ObjectTypeComposer') {
        throw new Error('opts.sourceTC for Resolver findById() should be instance of ObjectTypeComposer.');
    }
    const parser = new ElasticApiParser_1.default({
        elasticClient: opts.elasticClient,
        prefix: opts.prefix,
    });
    const findByIdFC = parser.generateFieldConfig('get', {
        index: opts.elasticIndex,
        type: opts.elasticType,
    });
    const type = (0, FindByIdOutput_1.getFindByIdOutputTC)(opts);
    return schemaComposer.createResolver({
        type,
        name: 'findById',
        kind: 'query',
        args: {
            id: 'String!',
        },
        resolve: (rp) => __awaiter(this, void 0, void 0, function* () {
            const { source, args, context, info } = rp;
            if (!args.id) {
                throw new Error(`Missed 'id' argument!`);
            }
            const res = yield findByIdFC.resolve(source, args, context, info);
            const { _index, _type, _id, _version, _source } = res || {};
            return Object.assign({ _index,
                _type,
                _id,
                _version }, _source);
        }),
    });
}
exports.default = createFindByIdResolver;
//# sourceMappingURL=findById.js.map