"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.fetchElasticMapping = exports.reorderKeys = exports.desc = exports.getTypeName = exports.prepareCommonOpts = void 0;
const graphql_compose_1 = require("graphql-compose");
function prepareCommonOpts(schemaComposer, opts = {}) {
    return Object.assign({ schemaComposer, getOrCreateOTC: (typeName, cfgOrThunk) => {
            return schemaComposer.getOrSet(typeName, () => {
                const tc = schemaComposer.createObjectTC((0, graphql_compose_1.isFunction)(cfgOrThunk) ? cfgOrThunk() : cfgOrThunk);
                return tc;
            });
        }, getOrCreateITC: (typeName, cfgOrThunk) => {
            return schemaComposer.getOrSet(typeName, () => {
                const tc = schemaComposer.createInputTC((0, graphql_compose_1.isFunction)(cfgOrThunk) ? cfgOrThunk() : cfgOrThunk);
                return tc;
            });
        }, getOrCreateETC: (typeName, cfgOrThunk) => {
            return schemaComposer.getOrSet(typeName, () => {
                const tc = schemaComposer.createEnumTC((0, graphql_compose_1.isFunction)(cfgOrThunk) ? cfgOrThunk() : cfgOrThunk);
                return tc;
            });
        } }, opts);
}
exports.prepareCommonOpts = prepareCommonOpts;
function getTypeName(name, opts) {
    return `${(opts && opts.prefix) || 'Elastic'}${name}${(opts && opts.postfix) || ''}`;
}
exports.getTypeName = getTypeName;
function desc(str) {
    return str.replace(/\n\s+/gi, ' ').replace(/^\s+/, '');
}
exports.desc = desc;
function reorderKeys(obj, names) {
    const orderedFields = {};
    const fields = Object.assign({}, obj);
    names.forEach((name) => {
        if (fields[name]) {
            orderedFields[name] = fields[name];
            delete fields[name];
        }
    });
    return Object.assign(Object.assign({}, orderedFields), fields);
}
exports.reorderKeys = reorderKeys;
function fetchElasticMapping(opts) {
    return __awaiter(this, void 0, void 0, function* () {
        if (!opts.elasticIndex || typeof opts.elasticIndex !== 'string') {
            throw new Error('Must provide `elasticIndex` string parameter from your Elastic server.');
        }
        if (!opts.elasticType || typeof opts.elasticType !== 'string') {
            throw new Error('Must provide `elasticType` string parameter from your Elastic server.');
        }
        if (!opts.elasticClient) {
            throw new Error('Must provide `elasticClient` Object parameter connected to your Elastic server.');
        }
        const elasticMapping = yield opts.elasticClient.indices.getMapping({
            index: opts.elasticIndex,
            type: opts.elasticType,
        });
        const baseIndex = elasticMapping[opts.elasticIndex] || Object.values(elasticMapping)[0];
        return baseIndex.mappings[opts.elasticType];
    });
}
exports.fetchElasticMapping = fetchElasticMapping;
//# sourceMappingURL=utils.js.map